
:autogenerated:

krotov.pulse_options module
===========================

.. currentmodule:: krotov.pulse_options

.. automodule:: krotov.pulse_options
    :members: PulseOptions
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        PulseOptions





    ``__all__``: :class:`PulseOptions <krotov.pulse_options.PulseOptions>`



    Reference
    ---------